[Python-3000-checkins] r54744 - in python/branches/p3yk/Lib: copy_reg.py test/test_bytes.py

guido.van.rossum python-3000-checkins at python.org
Wed Apr 11 06:37:50 CEST 2007


Author: guido.van.rossum
Date: Wed Apr 11 06:37:43 2007
New Revision: 54744

Modified:
   python/branches/p3yk/Lib/copy_reg.py
   python/branches/p3yk/Lib/test/test_bytes.py
Log:
An example of action-at-a-distance: fix the problems I had in test_io.py
without touching io.py or test_io.py.  The cause of the failure was that
bytes objects didn't pickle right.  As a stop-gap measure, I'm providing
bytes pickling via copy_reg.  Eventually, we should use a more efficient
protocol, e.g. __reduce_ex__ or __getstate__/__setstate__.


Modified: python/branches/p3yk/Lib/copy_reg.py
==============================================================================
--- python/branches/p3yk/Lib/test/test_bytes.py	(original)
+++ python/branches/p3yk/Lib/test/test_bytes.py	Wed Apr 11 06:37:43 2007
@@ -3,6 +3,8 @@
 import os
 import re
 import sys
+import pickle
+import cPickle
 import tempfile
 import unittest
 import test.test_support
@@ -633,6 +635,14 @@
         self.assertEqual(b.rpartition(b'ss'), (b'missi', b'ss', b'ippi'))
         self.assertEqual(b.rpartition(b'i'), (b'mississipp', b'i', b''))
 
+    def test_pickling(self):
+        for pm in pickle, cPickle:
+            for proto in range(pm.HIGHEST_PROTOCOL):
+                for b in b"", b"a", b"abc", b"\xffab\x80", b"\0\0\377\0\0":
+                    ps = pm.dumps(b, proto)
+                    q = pm.loads(ps)
+                    self.assertEqual(b, q)
+
     # Optimizations:
     # __iter__? (optimization)
     # __reversed__? (optimization)
@@ -640,8 +650,6 @@
     # XXX Some string methods?  (Those that don't use character properties)
     # lstrip, rstrip, strip?? (currently un-pepped)
     # join
-
-    # XXX pickle and marshal support?
     
     # There are tests in string_tests.py that are more
     # comprehensive for things like split, partition, etc.


More information about the Python-3000-checkins mailing list
--- python/branches/p3yk/Lib/copy_reg.py	(original)
+++ python/branches/p3yk/Lib/copy_reg.py	Wed Apr 11 06:37:43 2007
@@ -23,18 +23,12 @@
     if not callable(object):
         raise TypeError("constructors must be callable")
 
 # Example: provide pickling support for complex numbers.
 
-try:
-    complex
-except NameError:
-    pass
-else:
+def _pickle_bytes(b):
+    return bytes, (str(b),)
 
-    def pickle_complex(c):
-        return complex, (c.real, c.imag)
-
-    pickle(complex, pickle_complex, complex)
+pickle(bytes, _pickle_bytes)
 
 # Support for pickling new-style objects
 
@@ -23,18 +23,12 @@
         raise TypeError("constructors must be callable")
 
-# Example: provide pickling support for complex numbers.
+# Example: provide pickling support for bytes objects.
 

Modified: python/branches/p3yk/Lib/test/test_bytes.py
==============================================================================